#include "widget.h"
#include "ui_widget.h"

Widget::Widget(QWidget *parent) : QWidget(parent), ui(new Ui::Widget) {
    ui->setupUi(this);
    initDatabase();
    populateDataItem();
    connect(ui->deleteButton, SIGNAL(clicked(bool)),this,SLOT(remove()));
    connect(ui->addButton, SIGNAL(clicked(bool)),this,SLOT(addnew()));
    connect(ui->submitButton, SIGNAL(clicked(bool)),this,SLOT(save()));

}

Widget::~Widget() {
    closeDatabase();
    delete model;
    delete ui;
}

void Widget::populateDataItem(){
   model=new QSqlTableModel(0, db);
   model->setTable("test");
   model->setEditStrategy(QSqlTableModel::OnManualSubmit);
   model->select();
   model->setHeaderData(0, Qt::Horizontal, tr("ISBN"));
   model->setHeaderData(1, Qt::Horizontal, tr("Заголовок"));
   model->setHeaderData(2, Qt::Horizontal, tr("Год"));
   model->setHeaderData(3, Qt::Horizontal, tr("Издательство"));
   model->setHeaderData(5, Qt::Horizontal, tr("Цена"));
   model->setHeaderData(6, Qt::Horizontal, tr("Автор(ы)"));
   ui->tableView->setModel(model);
   ui->tableView->setAlternatingRowColors(true);
}

bool Widget::initDatabase(){
   db=QSqlDatabase::addDatabase("QMYSQL","MyLibrary");
   db.setHostName("localhost");
   db.setDatabaseName("MyLibrary");
   db.setUserName("root");
   db.setPassword("");
   return db.open();
}

void Widget::closeDatabase(){
   db.close();
}


void Widget::addnew(){
   int row=0;
   model->insertRows(row,1);
   model->setData(model->index(row,0),ui->edIsbn->text());
   model->setData(model->index(row,1),ui->edTitle->text());
   model->setData(model->index(row,2),ui->edEdition->text());
   model->setData(model->index(row,3),ui->edPublisher->text());
   model->setData(model->index(row,5),ui->dspinPrice->value());
   model->setData(model->index(row,6),ui->edAuthors->text());
}

void Widget::remove(){
   int row=ui->tableView->currentIndex().row();
   if(QMessageBox::question(0,"Удаление записи", "Запись с номером "
                            +QString::number(row+1)
                            +" будет удалена. Вы уверены?",
                            QMessageBox::No,QMessageBox::Yes)==
                            QMessageBox::Yes){
      model->removeRow(row);
   }
}

void Widget::save(){
   bool flag=model->submitAll();
   if(flag==false)
      QMessageBox::critical(0,"Ошибка", "Не могу сохранить изменения");
   else
      QMessageBox::information(0,"ОК",
      "Изменения успешно сохранены");
}
